--
-- Copyright (c) 2012-2019 Red Hat, Inc.
-- This program and the accompanying materials are made
-- available under the terms of the Eclipse Public License 2.0
-- which is available at https://www.eclipse.org/legal/epl-2.0/
--
-- SPDX-License-Identifier: EPL-2.0
--
-- Contributors:
--   Red Hat, Inc. - initial API and implementation
--

DROP TABLE installer_serverconf_attributes;
DROP TABLE installer_dependencies;
DROP TABLE installer_servers;
DROP TABLE installer_properties;
DROP TABLE installer;
